# Generated by Django 3.2.5 on 2023-02-02 08:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xj_flow', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='flownodetoaction',
            unique_together=set(),
        ),
    ]
